# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FeatureFlagArgs', 'FeatureFlag']

@pulumi.input_type
class FeatureFlagArgs:
    def __init__(__self__, *,
                 default_off_variation: pulumi.Input[_builtins.str],
                 default_on_variation: pulumi.Input[_builtins.str],
                 identifier: pulumi.Input[_builtins.str],
                 kind: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 permanent: pulumi.Input[_builtins.bool],
                 project_id: pulumi.Input[_builtins.str],
                 variations: pulumi.Input[Sequence[pulumi.Input['FeatureFlagVariationArgs']]],
                 archived: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environments: Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagEnvironmentArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagTagArgs']]]] = None):
        """
        The set of arguments for constructing a FeatureFlag resource.
        :param pulumi.Input[_builtins.str] default_off_variation: Which of the variations to use when the flag is toggled to off state
        :param pulumi.Input[_builtins.str] default_on_variation: Which of the variations to use when the flag is toggled to on state
        :param pulumi.Input[_builtins.str] identifier: Identifier of the Feature Flag
        :param pulumi.Input[_builtins.str] kind: The type of data the flag represents. Valid values are `boolean`, `int`, `string`, `json`
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier
        :param pulumi.Input[_builtins.bool] permanent: Whether or not the flag is permanent. If it is, it will never be flagged as stale
        :param pulumi.Input[_builtins.str] project_id: Project Identifier
        :param pulumi.Input[Sequence[pulumi.Input['FeatureFlagVariationArgs']]] variations: The options available for your flag
        :param pulumi.Input[_builtins.bool] archived: Whether or not the flag is archived.
        :param pulumi.Input[_builtins.str] description: Description of the Feature Flag
        :param pulumi.Input[Sequence[pulumi.Input['FeatureFlagEnvironmentArgs']]] environments: Environment Identifier
        :param pulumi.Input[_builtins.str] name: Name of the Feature Flag
        :param pulumi.Input[_builtins.str] owner: The owner of the flag
        :param pulumi.Input[Sequence[pulumi.Input['FeatureFlagTagArgs']]] tags: The tags for the flag
        """
        pulumi.set(__self__, "default_off_variation", default_off_variation)
        pulumi.set(__self__, "default_on_variation", default_on_variation)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "kind", kind)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "permanent", permanent)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "variations", variations)
        if archived is not None:
            pulumi.set(__self__, "archived", archived)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if environments is not None:
            pulumi.set(__self__, "environments", environments)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="defaultOffVariation")
    def default_off_variation(self) -> pulumi.Input[_builtins.str]:
        """
        Which of the variations to use when the flag is toggled to off state
        """
        return pulumi.get(self, "default_off_variation")

    @default_off_variation.setter
    def default_off_variation(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "default_off_variation", value)

    @_builtins.property
    @pulumi.getter(name="defaultOnVariation")
    def default_on_variation(self) -> pulumi.Input[_builtins.str]:
        """
        Which of the variations to use when the flag is toggled to on state
        """
        return pulumi.get(self, "default_on_variation")

    @default_on_variation.setter
    def default_on_variation(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "default_on_variation", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the Feature Flag
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def kind(self) -> pulumi.Input[_builtins.str]:
        """
        The type of data the flag represents. Valid values are `boolean`, `int`, `string`, `json`
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "kind", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Organization Identifier
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def permanent(self) -> pulumi.Input[_builtins.bool]:
        """
        Whether or not the flag is permanent. If it is, it will never be flagged as stale
        """
        return pulumi.get(self, "permanent")

    @permanent.setter
    def permanent(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "permanent", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Project Identifier
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def variations(self) -> pulumi.Input[Sequence[pulumi.Input['FeatureFlagVariationArgs']]]:
        """
        The options available for your flag
        """
        return pulumi.get(self, "variations")

    @variations.setter
    def variations(self, value: pulumi.Input[Sequence[pulumi.Input['FeatureFlagVariationArgs']]]):
        pulumi.set(self, "variations", value)

    @_builtins.property
    @pulumi.getter
    def archived(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not the flag is archived.
        """
        return pulumi.get(self, "archived")

    @archived.setter
    def archived(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "archived", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the Feature Flag
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def environments(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagEnvironmentArgs']]]]:
        """
        Environment Identifier
        """
        return pulumi.get(self, "environments")

    @environments.setter
    def environments(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagEnvironmentArgs']]]]):
        pulumi.set(self, "environments", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Feature Flag
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The owner of the flag
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagTagArgs']]]]:
        """
        The tags for the flag
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _FeatureFlagState:
    def __init__(__self__, *,
                 archived: Optional[pulumi.Input[_builtins.bool]] = None,
                 default_off_variation: Optional[pulumi.Input[_builtins.str]] = None,
                 default_on_variation: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environments: Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagEnvironmentArgs']]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 kind: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 permanent: Optional[pulumi.Input[_builtins.bool]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagTagArgs']]]] = None,
                 variations: Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagVariationArgs']]]] = None):
        """
        Input properties used for looking up and filtering FeatureFlag resources.
        :param pulumi.Input[_builtins.bool] archived: Whether or not the flag is archived.
        :param pulumi.Input[_builtins.str] default_off_variation: Which of the variations to use when the flag is toggled to off state
        :param pulumi.Input[_builtins.str] default_on_variation: Which of the variations to use when the flag is toggled to on state
        :param pulumi.Input[_builtins.str] description: Description of the Feature Flag
        :param pulumi.Input[Sequence[pulumi.Input['FeatureFlagEnvironmentArgs']]] environments: Environment Identifier
        :param pulumi.Input[_builtins.str] identifier: Identifier of the Feature Flag
        :param pulumi.Input[_builtins.str] kind: The type of data the flag represents. Valid values are `boolean`, `int`, `string`, `json`
        :param pulumi.Input[_builtins.str] name: Name of the Feature Flag
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier
        :param pulumi.Input[_builtins.str] owner: The owner of the flag
        :param pulumi.Input[_builtins.bool] permanent: Whether or not the flag is permanent. If it is, it will never be flagged as stale
        :param pulumi.Input[_builtins.str] project_id: Project Identifier
        :param pulumi.Input[Sequence[pulumi.Input['FeatureFlagTagArgs']]] tags: The tags for the flag
        :param pulumi.Input[Sequence[pulumi.Input['FeatureFlagVariationArgs']]] variations: The options available for your flag
        """
        if archived is not None:
            pulumi.set(__self__, "archived", archived)
        if default_off_variation is not None:
            pulumi.set(__self__, "default_off_variation", default_off_variation)
        if default_on_variation is not None:
            pulumi.set(__self__, "default_on_variation", default_on_variation)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if environments is not None:
            pulumi.set(__self__, "environments", environments)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if kind is not None:
            pulumi.set(__self__, "kind", kind)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if permanent is not None:
            pulumi.set(__self__, "permanent", permanent)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if variations is not None:
            pulumi.set(__self__, "variations", variations)

    @_builtins.property
    @pulumi.getter
    def archived(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not the flag is archived.
        """
        return pulumi.get(self, "archived")

    @archived.setter
    def archived(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "archived", value)

    @_builtins.property
    @pulumi.getter(name="defaultOffVariation")
    def default_off_variation(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Which of the variations to use when the flag is toggled to off state
        """
        return pulumi.get(self, "default_off_variation")

    @default_off_variation.setter
    def default_off_variation(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_off_variation", value)

    @_builtins.property
    @pulumi.getter(name="defaultOnVariation")
    def default_on_variation(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Which of the variations to use when the flag is toggled to on state
        """
        return pulumi.get(self, "default_on_variation")

    @default_on_variation.setter
    def default_on_variation(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_on_variation", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the Feature Flag
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def environments(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagEnvironmentArgs']]]]:
        """
        Environment Identifier
        """
        return pulumi.get(self, "environments")

    @environments.setter
    def environments(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagEnvironmentArgs']]]]):
        pulumi.set(self, "environments", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the Feature Flag
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of data the flag represents. Valid values are `boolean`, `int`, `string`, `json`
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "kind", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Feature Flag
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization Identifier
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The owner of the flag
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter
    def permanent(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not the flag is permanent. If it is, it will never be flagged as stale
        """
        return pulumi.get(self, "permanent")

    @permanent.setter
    def permanent(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "permanent", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project Identifier
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagTagArgs']]]]:
        """
        The tags for the flag
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def variations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagVariationArgs']]]]:
        """
        The options available for your flag
        """
        return pulumi.get(self, "variations")

    @variations.setter
    def variations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FeatureFlagVariationArgs']]]]):
        pulumi.set(self, "variations", value)


@pulumi.type_token("harness:platform/featureFlag:FeatureFlag")
class FeatureFlag(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 archived: Optional[pulumi.Input[_builtins.bool]] = None,
                 default_off_variation: Optional[pulumi.Input[_builtins.str]] = None,
                 default_on_variation: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environments: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagEnvironmentArgs', 'FeatureFlagEnvironmentArgsDict']]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 kind: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 permanent: Optional[pulumi.Input[_builtins.bool]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagTagArgs', 'FeatureFlagTagArgsDict']]]]] = None,
                 variations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagVariationArgs', 'FeatureFlagVariationArgsDict']]]]] = None,
                 __props__=None):
        """
        Resource for managing Feature Flags.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] archived: Whether or not the flag is archived.
        :param pulumi.Input[_builtins.str] default_off_variation: Which of the variations to use when the flag is toggled to off state
        :param pulumi.Input[_builtins.str] default_on_variation: Which of the variations to use when the flag is toggled to on state
        :param pulumi.Input[_builtins.str] description: Description of the Feature Flag
        :param pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagEnvironmentArgs', 'FeatureFlagEnvironmentArgsDict']]]] environments: Environment Identifier
        :param pulumi.Input[_builtins.str] identifier: Identifier of the Feature Flag
        :param pulumi.Input[_builtins.str] kind: The type of data the flag represents. Valid values are `boolean`, `int`, `string`, `json`
        :param pulumi.Input[_builtins.str] name: Name of the Feature Flag
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier
        :param pulumi.Input[_builtins.str] owner: The owner of the flag
        :param pulumi.Input[_builtins.bool] permanent: Whether or not the flag is permanent. If it is, it will never be flagged as stale
        :param pulumi.Input[_builtins.str] project_id: Project Identifier
        :param pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagTagArgs', 'FeatureFlagTagArgsDict']]]] tags: The tags for the flag
        :param pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagVariationArgs', 'FeatureFlagVariationArgsDict']]]] variations: The options available for your flag
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FeatureFlagArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing Feature Flags.

        :param str resource_name: The name of the resource.
        :param FeatureFlagArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FeatureFlagArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 archived: Optional[pulumi.Input[_builtins.bool]] = None,
                 default_off_variation: Optional[pulumi.Input[_builtins.str]] = None,
                 default_on_variation: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environments: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagEnvironmentArgs', 'FeatureFlagEnvironmentArgsDict']]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 kind: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 permanent: Optional[pulumi.Input[_builtins.bool]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagTagArgs', 'FeatureFlagTagArgsDict']]]]] = None,
                 variations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagVariationArgs', 'FeatureFlagVariationArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FeatureFlagArgs.__new__(FeatureFlagArgs)

            __props__.__dict__["archived"] = archived
            if default_off_variation is None and not opts.urn:
                raise TypeError("Missing required property 'default_off_variation'")
            __props__.__dict__["default_off_variation"] = default_off_variation
            if default_on_variation is None and not opts.urn:
                raise TypeError("Missing required property 'default_on_variation'")
            __props__.__dict__["default_on_variation"] = default_on_variation
            __props__.__dict__["description"] = description
            __props__.__dict__["environments"] = environments
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            if kind is None and not opts.urn:
                raise TypeError("Missing required property 'kind'")
            __props__.__dict__["kind"] = kind
            __props__.__dict__["name"] = name
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["owner"] = owner
            if permanent is None and not opts.urn:
                raise TypeError("Missing required property 'permanent'")
            __props__.__dict__["permanent"] = permanent
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            if variations is None and not opts.urn:
                raise TypeError("Missing required property 'variations'")
            __props__.__dict__["variations"] = variations
        super(FeatureFlag, __self__).__init__(
            'harness:platform/featureFlag:FeatureFlag',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            archived: Optional[pulumi.Input[_builtins.bool]] = None,
            default_off_variation: Optional[pulumi.Input[_builtins.str]] = None,
            default_on_variation: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            environments: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagEnvironmentArgs', 'FeatureFlagEnvironmentArgsDict']]]]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            kind: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            owner: Optional[pulumi.Input[_builtins.str]] = None,
            permanent: Optional[pulumi.Input[_builtins.bool]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagTagArgs', 'FeatureFlagTagArgsDict']]]]] = None,
            variations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagVariationArgs', 'FeatureFlagVariationArgsDict']]]]] = None) -> 'FeatureFlag':
        """
        Get an existing FeatureFlag resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] archived: Whether or not the flag is archived.
        :param pulumi.Input[_builtins.str] default_off_variation: Which of the variations to use when the flag is toggled to off state
        :param pulumi.Input[_builtins.str] default_on_variation: Which of the variations to use when the flag is toggled to on state
        :param pulumi.Input[_builtins.str] description: Description of the Feature Flag
        :param pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagEnvironmentArgs', 'FeatureFlagEnvironmentArgsDict']]]] environments: Environment Identifier
        :param pulumi.Input[_builtins.str] identifier: Identifier of the Feature Flag
        :param pulumi.Input[_builtins.str] kind: The type of data the flag represents. Valid values are `boolean`, `int`, `string`, `json`
        :param pulumi.Input[_builtins.str] name: Name of the Feature Flag
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier
        :param pulumi.Input[_builtins.str] owner: The owner of the flag
        :param pulumi.Input[_builtins.bool] permanent: Whether or not the flag is permanent. If it is, it will never be flagged as stale
        :param pulumi.Input[_builtins.str] project_id: Project Identifier
        :param pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagTagArgs', 'FeatureFlagTagArgsDict']]]] tags: The tags for the flag
        :param pulumi.Input[Sequence[pulumi.Input[Union['FeatureFlagVariationArgs', 'FeatureFlagVariationArgsDict']]]] variations: The options available for your flag
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FeatureFlagState.__new__(_FeatureFlagState)

        __props__.__dict__["archived"] = archived
        __props__.__dict__["default_off_variation"] = default_off_variation
        __props__.__dict__["default_on_variation"] = default_on_variation
        __props__.__dict__["description"] = description
        __props__.__dict__["environments"] = environments
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["kind"] = kind
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["permanent"] = permanent
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["variations"] = variations
        return FeatureFlag(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def archived(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether or not the flag is archived.
        """
        return pulumi.get(self, "archived")

    @_builtins.property
    @pulumi.getter(name="defaultOffVariation")
    def default_off_variation(self) -> pulumi.Output[_builtins.str]:
        """
        Which of the variations to use when the flag is toggled to off state
        """
        return pulumi.get(self, "default_off_variation")

    @_builtins.property
    @pulumi.getter(name="defaultOnVariation")
    def default_on_variation(self) -> pulumi.Output[_builtins.str]:
        """
        Which of the variations to use when the flag is toggled to on state
        """
        return pulumi.get(self, "default_on_variation")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the Feature Flag
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def environments(self) -> pulumi.Output[Optional[Sequence['outputs.FeatureFlagEnvironment']]]:
        """
        Environment Identifier
        """
        return pulumi.get(self, "environments")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the Feature Flag
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> pulumi.Output[_builtins.str]:
        """
        The type of data the flag represents. Valid values are `boolean`, `int`, `string`, `json`
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Feature Flag
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Organization Identifier
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The owner of the flag
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter
    def permanent(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether or not the flag is permanent. If it is, it will never be flagged as stale
        """
        return pulumi.get(self, "permanent")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Project Identifier
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence['outputs.FeatureFlagTag']]]:
        """
        The tags for the flag
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def variations(self) -> pulumi.Output[Sequence['outputs.FeatureFlagVariation']]:
        """
        The options available for your flag
        """
        return pulumi.get(self, "variations")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetVaultConnectorResult',
    'AwaitableGetVaultConnectorResult',
    'get_vault_connector',
    'get_vault_connector_output',
]

@pulumi.output_type
class GetVaultConnectorResult:
    """
    A collection of values returned by getVaultConnector.
    """
    def __init__(__self__, access_type=None, app_role_id=None, auth_token=None, aws_region=None, base_path=None, default=None, delegate_selectors=None, description=None, execute_on_delegate=None, id=None, identifier=None, is_default=None, is_read_only=None, k8s_auth_endpoint=None, name=None, namespace=None, org_id=None, project_id=None, read_only=None, renew_app_role_token=None, renewal_interval_minutes=None, secret_engine_manually_configured=None, secret_engine_name=None, secret_engine_version=None, secret_id=None, service_account_token_path=None, sink_path=None, tags=None, use_aws_iam=None, use_jwt_auth=None, use_k8s_auth=None, use_vault_agent=None, vault_aws_iam_role=None, vault_jwt_auth_path=None, vault_jwt_auth_role=None, vault_k8s_auth_role=None, vault_url=None, xvault_aws_iam_server_id=None):
        if access_type and not isinstance(access_type, str):
            raise TypeError("Expected argument 'access_type' to be a str")
        pulumi.set(__self__, "access_type", access_type)
        if app_role_id and not isinstance(app_role_id, str):
            raise TypeError("Expected argument 'app_role_id' to be a str")
        pulumi.set(__self__, "app_role_id", app_role_id)
        if auth_token and not isinstance(auth_token, str):
            raise TypeError("Expected argument 'auth_token' to be a str")
        pulumi.set(__self__, "auth_token", auth_token)
        if aws_region and not isinstance(aws_region, str):
            raise TypeError("Expected argument 'aws_region' to be a str")
        pulumi.set(__self__, "aws_region", aws_region)
        if base_path and not isinstance(base_path, str):
            raise TypeError("Expected argument 'base_path' to be a str")
        pulumi.set(__self__, "base_path", base_path)
        if default and not isinstance(default, bool):
            raise TypeError("Expected argument 'default' to be a bool")
        pulumi.set(__self__, "default", default)
        if delegate_selectors and not isinstance(delegate_selectors, list):
            raise TypeError("Expected argument 'delegate_selectors' to be a list")
        pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if execute_on_delegate and not isinstance(execute_on_delegate, bool):
            raise TypeError("Expected argument 'execute_on_delegate' to be a bool")
        pulumi.set(__self__, "execute_on_delegate", execute_on_delegate)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if is_default and not isinstance(is_default, bool):
            raise TypeError("Expected argument 'is_default' to be a bool")
        pulumi.set(__self__, "is_default", is_default)
        if is_read_only and not isinstance(is_read_only, bool):
            raise TypeError("Expected argument 'is_read_only' to be a bool")
        pulumi.set(__self__, "is_read_only", is_read_only)
        if k8s_auth_endpoint and not isinstance(k8s_auth_endpoint, str):
            raise TypeError("Expected argument 'k8s_auth_endpoint' to be a str")
        pulumi.set(__self__, "k8s_auth_endpoint", k8s_auth_endpoint)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if read_only and not isinstance(read_only, bool):
            raise TypeError("Expected argument 'read_only' to be a bool")
        pulumi.set(__self__, "read_only", read_only)
        if renew_app_role_token and not isinstance(renew_app_role_token, bool):
            raise TypeError("Expected argument 'renew_app_role_token' to be a bool")
        pulumi.set(__self__, "renew_app_role_token", renew_app_role_token)
        if renewal_interval_minutes and not isinstance(renewal_interval_minutes, int):
            raise TypeError("Expected argument 'renewal_interval_minutes' to be a int")
        pulumi.set(__self__, "renewal_interval_minutes", renewal_interval_minutes)
        if secret_engine_manually_configured and not isinstance(secret_engine_manually_configured, bool):
            raise TypeError("Expected argument 'secret_engine_manually_configured' to be a bool")
        pulumi.set(__self__, "secret_engine_manually_configured", secret_engine_manually_configured)
        if secret_engine_name and not isinstance(secret_engine_name, str):
            raise TypeError("Expected argument 'secret_engine_name' to be a str")
        pulumi.set(__self__, "secret_engine_name", secret_engine_name)
        if secret_engine_version and not isinstance(secret_engine_version, int):
            raise TypeError("Expected argument 'secret_engine_version' to be a int")
        pulumi.set(__self__, "secret_engine_version", secret_engine_version)
        if secret_id and not isinstance(secret_id, str):
            raise TypeError("Expected argument 'secret_id' to be a str")
        pulumi.set(__self__, "secret_id", secret_id)
        if service_account_token_path and not isinstance(service_account_token_path, str):
            raise TypeError("Expected argument 'service_account_token_path' to be a str")
        pulumi.set(__self__, "service_account_token_path", service_account_token_path)
        if sink_path and not isinstance(sink_path, str):
            raise TypeError("Expected argument 'sink_path' to be a str")
        pulumi.set(__self__, "sink_path", sink_path)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if use_aws_iam and not isinstance(use_aws_iam, bool):
            raise TypeError("Expected argument 'use_aws_iam' to be a bool")
        pulumi.set(__self__, "use_aws_iam", use_aws_iam)
        if use_jwt_auth and not isinstance(use_jwt_auth, bool):
            raise TypeError("Expected argument 'use_jwt_auth' to be a bool")
        pulumi.set(__self__, "use_jwt_auth", use_jwt_auth)
        if use_k8s_auth and not isinstance(use_k8s_auth, bool):
            raise TypeError("Expected argument 'use_k8s_auth' to be a bool")
        pulumi.set(__self__, "use_k8s_auth", use_k8s_auth)
        if use_vault_agent and not isinstance(use_vault_agent, bool):
            raise TypeError("Expected argument 'use_vault_agent' to be a bool")
        pulumi.set(__self__, "use_vault_agent", use_vault_agent)
        if vault_aws_iam_role and not isinstance(vault_aws_iam_role, str):
            raise TypeError("Expected argument 'vault_aws_iam_role' to be a str")
        pulumi.set(__self__, "vault_aws_iam_role", vault_aws_iam_role)
        if vault_jwt_auth_path and not isinstance(vault_jwt_auth_path, str):
            raise TypeError("Expected argument 'vault_jwt_auth_path' to be a str")
        pulumi.set(__self__, "vault_jwt_auth_path", vault_jwt_auth_path)
        if vault_jwt_auth_role and not isinstance(vault_jwt_auth_role, str):
            raise TypeError("Expected argument 'vault_jwt_auth_role' to be a str")
        pulumi.set(__self__, "vault_jwt_auth_role", vault_jwt_auth_role)
        if vault_k8s_auth_role and not isinstance(vault_k8s_auth_role, str):
            raise TypeError("Expected argument 'vault_k8s_auth_role' to be a str")
        pulumi.set(__self__, "vault_k8s_auth_role", vault_k8s_auth_role)
        if vault_url and not isinstance(vault_url, str):
            raise TypeError("Expected argument 'vault_url' to be a str")
        pulumi.set(__self__, "vault_url", vault_url)
        if xvault_aws_iam_server_id and not isinstance(xvault_aws_iam_server_id, str):
            raise TypeError("Expected argument 'xvault_aws_iam_server_id' to be a str")
        pulumi.set(__self__, "xvault_aws_iam_server_id", xvault_aws_iam_server_id)

    @_builtins.property
    @pulumi.getter(name="accessType")
    def access_type(self) -> _builtins.str:
        """
        Access type.
        """
        return pulumi.get(self, "access_type")

    @_builtins.property
    @pulumi.getter(name="appRoleId")
    def app_role_id(self) -> _builtins.str:
        """
        ID of App Role.
        """
        return pulumi.get(self, "app_role_id")

    @_builtins.property
    @pulumi.getter(name="authToken")
    def auth_token(self) -> _builtins.str:
        """
        The authentication token for Vault.
        """
        return pulumi.get(self, "auth_token")

    @_builtins.property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> _builtins.str:
        """
        The AWS region where AWS IAM auth will happen.
        """
        return pulumi.get(self, "aws_region")

    @_builtins.property
    @pulumi.getter(name="basePath")
    def base_path(self) -> _builtins.str:
        """
        The location of the Vault directory where Secret will be stored.
        """
        return pulumi.get(self, "base_path")

    @_builtins.property
    @pulumi.getter
    def default(self) -> _builtins.bool:
        """
        Is default or not.
        """
        return pulumi.get(self, "default")

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Sequence[_builtins.str]:
        """
        List of Delegate Selectors that belong to the same Delegate and are used to connect to the Secret Manager.
        """
        return pulumi.get(self, "delegate_selectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="executeOnDelegate")
    def execute_on_delegate(self) -> _builtins.bool:
        """
        Execute on delegate or not.
        """
        return pulumi.get(self, "execute_on_delegate")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> _builtins.bool:
        """
        Is default or not.
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter(name="isReadOnly")
    def is_read_only(self) -> _builtins.bool:
        """
        Read only or not.
        """
        return pulumi.get(self, "is_read_only")

    @_builtins.property
    @pulumi.getter(name="k8sAuthEndpoint")
    def k8s_auth_endpoint(self) -> _builtins.str:
        """
        The path where kubernetes auth is enabled in Vault.
        """
        return pulumi.get(self, "k8s_auth_endpoint")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def namespace(self) -> _builtins.str:
        """
        The Vault namespace where Secret will be created.
        """
        return pulumi.get(self, "namespace")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> _builtins.bool:
        """
        Read only.
        """
        return pulumi.get(self, "read_only")

    @_builtins.property
    @pulumi.getter(name="renewAppRoleToken")
    def renew_app_role_token(self) -> _builtins.bool:
        """
        Boolean value to indicate if appRole token renewal is enabled or not.
        """
        return pulumi.get(self, "renew_app_role_token")

    @_builtins.property
    @pulumi.getter(name="renewalIntervalMinutes")
    def renewal_interval_minutes(self) -> _builtins.int:
        """
        The time interval for token renewal.
        """
        return pulumi.get(self, "renewal_interval_minutes")

    @_builtins.property
    @pulumi.getter(name="secretEngineManuallyConfigured")
    def secret_engine_manually_configured(self) -> _builtins.bool:
        """
        Manually entered Secret Engine.
        """
        return pulumi.get(self, "secret_engine_manually_configured")

    @_builtins.property
    @pulumi.getter(name="secretEngineName")
    def secret_engine_name(self) -> _builtins.str:
        """
        Name of the Secret Engine.
        """
        return pulumi.get(self, "secret_engine_name")

    @_builtins.property
    @pulumi.getter(name="secretEngineVersion")
    def secret_engine_version(self) -> _builtins.int:
        """
        Version of Secret Engine.
        """
        return pulumi.get(self, "secret_engine_version")

    @_builtins.property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> _builtins.str:
        """
        ID of the Secret.
        """
        return pulumi.get(self, "secret_id")

    @_builtins.property
    @pulumi.getter(name="serviceAccountTokenPath")
    def service_account_token_path(self) -> _builtins.str:
        """
        The SA token path where the token is mounted in the K8s Pod.
        """
        return pulumi.get(self, "service_account_token_path")

    @_builtins.property
    @pulumi.getter(name="sinkPath")
    def sink_path(self) -> _builtins.str:
        """
        The location at which auth token is to be read from.
        """
        return pulumi.get(self, "sink_path")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="useAwsIam")
    def use_aws_iam(self) -> _builtins.bool:
        """
        Boolean value to indicate if AWS IAM is used for authentication.
        """
        return pulumi.get(self, "use_aws_iam")

    @_builtins.property
    @pulumi.getter(name="useJwtAuth")
    def use_jwt_auth(self) -> _builtins.bool:
        """
        Boolean value to indicate if JWT is used for authentication.
        """
        return pulumi.get(self, "use_jwt_auth")

    @_builtins.property
    @pulumi.getter(name="useK8sAuth")
    def use_k8s_auth(self) -> _builtins.bool:
        """
        Boolean value to indicate if K8s Auth is used for authentication.
        """
        return pulumi.get(self, "use_k8s_auth")

    @_builtins.property
    @pulumi.getter(name="useVaultAgent")
    def use_vault_agent(self) -> _builtins.bool:
        """
        Boolean value to indicate if Vault Agent is used for authentication.
        """
        return pulumi.get(self, "use_vault_agent")

    @_builtins.property
    @pulumi.getter(name="vaultAwsIamRole")
    def vault_aws_iam_role(self) -> _builtins.str:
        """
        The Vault role defined to bind to AWS IAM account/role being accessed.
        """
        return pulumi.get(self, "vault_aws_iam_role")

    @_builtins.property
    @pulumi.getter(name="vaultJwtAuthPath")
    def vault_jwt_auth_path(self) -> _builtins.str:
        """
        Custom path at with JWT auth in enabled for Vault
        """
        return pulumi.get(self, "vault_jwt_auth_path")

    @_builtins.property
    @pulumi.getter(name="vaultJwtAuthRole")
    def vault_jwt_auth_role(self) -> _builtins.str:
        """
        The Vault role defined with JWT auth type for accessing Vault as per policies binded.
        """
        return pulumi.get(self, "vault_jwt_auth_role")

    @_builtins.property
    @pulumi.getter(name="vaultK8sAuthRole")
    def vault_k8s_auth_role(self) -> _builtins.str:
        """
        The role where K8s auth will happen.
        """
        return pulumi.get(self, "vault_k8s_auth_role")

    @_builtins.property
    @pulumi.getter(name="vaultUrl")
    def vault_url(self) -> _builtins.str:
        """
        URL of the HashiCorp Vault.
        """
        return pulumi.get(self, "vault_url")

    @_builtins.property
    @pulumi.getter(name="xvaultAwsIamServerId")
    def xvault_aws_iam_server_id(self) -> _builtins.str:
        """
        The AWS IAM Header Server ID that has been configured for this AWS IAM instance.
        """
        return pulumi.get(self, "xvault_aws_iam_server_id")


class AwaitableGetVaultConnectorResult(GetVaultConnectorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVaultConnectorResult(
            access_type=self.access_type,
            app_role_id=self.app_role_id,
            auth_token=self.auth_token,
            aws_region=self.aws_region,
            base_path=self.base_path,
            default=self.default,
            delegate_selectors=self.delegate_selectors,
            description=self.description,
            execute_on_delegate=self.execute_on_delegate,
            id=self.id,
            identifier=self.identifier,
            is_default=self.is_default,
            is_read_only=self.is_read_only,
            k8s_auth_endpoint=self.k8s_auth_endpoint,
            name=self.name,
            namespace=self.namespace,
            org_id=self.org_id,
            project_id=self.project_id,
            read_only=self.read_only,
            renew_app_role_token=self.renew_app_role_token,
            renewal_interval_minutes=self.renewal_interval_minutes,
            secret_engine_manually_configured=self.secret_engine_manually_configured,
            secret_engine_name=self.secret_engine_name,
            secret_engine_version=self.secret_engine_version,
            secret_id=self.secret_id,
            service_account_token_path=self.service_account_token_path,
            sink_path=self.sink_path,
            tags=self.tags,
            use_aws_iam=self.use_aws_iam,
            use_jwt_auth=self.use_jwt_auth,
            use_k8s_auth=self.use_k8s_auth,
            use_vault_agent=self.use_vault_agent,
            vault_aws_iam_role=self.vault_aws_iam_role,
            vault_jwt_auth_path=self.vault_jwt_auth_path,
            vault_jwt_auth_role=self.vault_jwt_auth_role,
            vault_k8s_auth_role=self.vault_k8s_auth_role,
            vault_url=self.vault_url,
            xvault_aws_iam_server_id=self.xvault_aws_iam_server_id)


def get_vault_connector(identifier: Optional[_builtins.str] = None,
                        name: Optional[_builtins.str] = None,
                        org_id: Optional[_builtins.str] = None,
                        project_id: Optional[_builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVaultConnectorResult:
    """
    DataSource for looking up a Vault connector in Harness.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_vault_connector(identifier="identifier")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getVaultConnector:getVaultConnector', __args__, opts=opts, typ=GetVaultConnectorResult).value

    return AwaitableGetVaultConnectorResult(
        access_type=pulumi.get(__ret__, 'access_type'),
        app_role_id=pulumi.get(__ret__, 'app_role_id'),
        auth_token=pulumi.get(__ret__, 'auth_token'),
        aws_region=pulumi.get(__ret__, 'aws_region'),
        base_path=pulumi.get(__ret__, 'base_path'),
        default=pulumi.get(__ret__, 'default'),
        delegate_selectors=pulumi.get(__ret__, 'delegate_selectors'),
        description=pulumi.get(__ret__, 'description'),
        execute_on_delegate=pulumi.get(__ret__, 'execute_on_delegate'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        is_default=pulumi.get(__ret__, 'is_default'),
        is_read_only=pulumi.get(__ret__, 'is_read_only'),
        k8s_auth_endpoint=pulumi.get(__ret__, 'k8s_auth_endpoint'),
        name=pulumi.get(__ret__, 'name'),
        namespace=pulumi.get(__ret__, 'namespace'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        read_only=pulumi.get(__ret__, 'read_only'),
        renew_app_role_token=pulumi.get(__ret__, 'renew_app_role_token'),
        renewal_interval_minutes=pulumi.get(__ret__, 'renewal_interval_minutes'),
        secret_engine_manually_configured=pulumi.get(__ret__, 'secret_engine_manually_configured'),
        secret_engine_name=pulumi.get(__ret__, 'secret_engine_name'),
        secret_engine_version=pulumi.get(__ret__, 'secret_engine_version'),
        secret_id=pulumi.get(__ret__, 'secret_id'),
        service_account_token_path=pulumi.get(__ret__, 'service_account_token_path'),
        sink_path=pulumi.get(__ret__, 'sink_path'),
        tags=pulumi.get(__ret__, 'tags'),
        use_aws_iam=pulumi.get(__ret__, 'use_aws_iam'),
        use_jwt_auth=pulumi.get(__ret__, 'use_jwt_auth'),
        use_k8s_auth=pulumi.get(__ret__, 'use_k8s_auth'),
        use_vault_agent=pulumi.get(__ret__, 'use_vault_agent'),
        vault_aws_iam_role=pulumi.get(__ret__, 'vault_aws_iam_role'),
        vault_jwt_auth_path=pulumi.get(__ret__, 'vault_jwt_auth_path'),
        vault_jwt_auth_role=pulumi.get(__ret__, 'vault_jwt_auth_role'),
        vault_k8s_auth_role=pulumi.get(__ret__, 'vault_k8s_auth_role'),
        vault_url=pulumi.get(__ret__, 'vault_url'),
        xvault_aws_iam_server_id=pulumi.get(__ret__, 'xvault_aws_iam_server_id'))
def get_vault_connector_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                               name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVaultConnectorResult]:
    """
    DataSource for looking up a Vault connector in Harness.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_vault_connector(identifier="identifier")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getVaultConnector:getVaultConnector', __args__, opts=opts, typ=GetVaultConnectorResult)
    return __ret__.apply(lambda __response__: GetVaultConnectorResult(
        access_type=pulumi.get(__response__, 'access_type'),
        app_role_id=pulumi.get(__response__, 'app_role_id'),
        auth_token=pulumi.get(__response__, 'auth_token'),
        aws_region=pulumi.get(__response__, 'aws_region'),
        base_path=pulumi.get(__response__, 'base_path'),
        default=pulumi.get(__response__, 'default'),
        delegate_selectors=pulumi.get(__response__, 'delegate_selectors'),
        description=pulumi.get(__response__, 'description'),
        execute_on_delegate=pulumi.get(__response__, 'execute_on_delegate'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        is_default=pulumi.get(__response__, 'is_default'),
        is_read_only=pulumi.get(__response__, 'is_read_only'),
        k8s_auth_endpoint=pulumi.get(__response__, 'k8s_auth_endpoint'),
        name=pulumi.get(__response__, 'name'),
        namespace=pulumi.get(__response__, 'namespace'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        read_only=pulumi.get(__response__, 'read_only'),
        renew_app_role_token=pulumi.get(__response__, 'renew_app_role_token'),
        renewal_interval_minutes=pulumi.get(__response__, 'renewal_interval_minutes'),
        secret_engine_manually_configured=pulumi.get(__response__, 'secret_engine_manually_configured'),
        secret_engine_name=pulumi.get(__response__, 'secret_engine_name'),
        secret_engine_version=pulumi.get(__response__, 'secret_engine_version'),
        secret_id=pulumi.get(__response__, 'secret_id'),
        service_account_token_path=pulumi.get(__response__, 'service_account_token_path'),
        sink_path=pulumi.get(__response__, 'sink_path'),
        tags=pulumi.get(__response__, 'tags'),
        use_aws_iam=pulumi.get(__response__, 'use_aws_iam'),
        use_jwt_auth=pulumi.get(__response__, 'use_jwt_auth'),
        use_k8s_auth=pulumi.get(__response__, 'use_k8s_auth'),
        use_vault_agent=pulumi.get(__response__, 'use_vault_agent'),
        vault_aws_iam_role=pulumi.get(__response__, 'vault_aws_iam_role'),
        vault_jwt_auth_path=pulumi.get(__response__, 'vault_jwt_auth_path'),
        vault_jwt_auth_role=pulumi.get(__response__, 'vault_jwt_auth_role'),
        vault_k8s_auth_role=pulumi.get(__response__, 'vault_k8s_auth_role'),
        vault_url=pulumi.get(__response__, 'vault_url'),
        xvault_aws_iam_server_id=pulumi.get(__response__, 'xvault_aws_iam_server_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetUserResult',
    'AwaitableGetUserResult',
    'get_user',
    'get_user_output',
]

@pulumi.output_type
class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, email=None, id=None, is_email_verified=None, is_imported_from_identity_provider=None, is_password_expired=None, is_two_factor_auth_enabled=None, is_user_locked=None, name=None):
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_email_verified and not isinstance(is_email_verified, bool):
            raise TypeError("Expected argument 'is_email_verified' to be a bool")
        pulumi.set(__self__, "is_email_verified", is_email_verified)
        if is_imported_from_identity_provider and not isinstance(is_imported_from_identity_provider, bool):
            raise TypeError("Expected argument 'is_imported_from_identity_provider' to be a bool")
        pulumi.set(__self__, "is_imported_from_identity_provider", is_imported_from_identity_provider)
        if is_password_expired and not isinstance(is_password_expired, bool):
            raise TypeError("Expected argument 'is_password_expired' to be a bool")
        pulumi.set(__self__, "is_password_expired", is_password_expired)
        if is_two_factor_auth_enabled and not isinstance(is_two_factor_auth_enabled, bool):
            raise TypeError("Expected argument 'is_two_factor_auth_enabled' to be a bool")
        pulumi.set(__self__, "is_two_factor_auth_enabled", is_two_factor_auth_enabled)
        if is_user_locked and not isinstance(is_user_locked, bool):
            raise TypeError("Expected argument 'is_user_locked' to be a bool")
        pulumi.set(__self__, "is_user_locked", is_user_locked)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[_builtins.str]:
        """
        The email of the user.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the user
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isEmailVerified")
    def is_email_verified(self) -> _builtins.bool:
        """
        Flag indicating whether or not the users email has been verified.
        """
        return pulumi.get(self, "is_email_verified")

    @_builtins.property
    @pulumi.getter(name="isImportedFromIdentityProvider")
    def is_imported_from_identity_provider(self) -> _builtins.bool:
        """
        Flag indicating whether or not the user was imported from an identity provider.
        """
        return pulumi.get(self, "is_imported_from_identity_provider")

    @_builtins.property
    @pulumi.getter(name="isPasswordExpired")
    def is_password_expired(self) -> _builtins.bool:
        """
        Flag indicating whether or not the users password has expired.
        """
        return pulumi.get(self, "is_password_expired")

    @_builtins.property
    @pulumi.getter(name="isTwoFactorAuthEnabled")
    def is_two_factor_auth_enabled(self) -> _builtins.bool:
        """
        Flag indicating whether or not two-factor authentication is enabled for the user.
        """
        return pulumi.get(self, "is_two_factor_auth_enabled")

    @_builtins.property
    @pulumi.getter(name="isUserLocked")
    def is_user_locked(self) -> _builtins.bool:
        """
        Flag indicating whether or not the user is locked out.
        """
        return pulumi.get(self, "is_user_locked")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the user.
        """
        return pulumi.get(self, "name")


class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            email=self.email,
            id=self.id,
            is_email_verified=self.is_email_verified,
            is_imported_from_identity_provider=self.is_imported_from_identity_provider,
            is_password_expired=self.is_password_expired,
            is_two_factor_auth_enabled=self.is_two_factor_auth_enabled,
            is_user_locked=self.is_user_locked,
            name=self.name)


def get_user(email: Optional[_builtins.str] = None,
             id: Optional[_builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserResult:
    """
    Data source for retrieving a Harness user


    :param _builtins.str email: The email of the user.
    :param _builtins.str id: Unique identifier of the user
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:index/getUser:getUser', __args__, opts=opts, typ=GetUserResult).value

    return AwaitableGetUserResult(
        email=pulumi.get(__ret__, 'email'),
        id=pulumi.get(__ret__, 'id'),
        is_email_verified=pulumi.get(__ret__, 'is_email_verified'),
        is_imported_from_identity_provider=pulumi.get(__ret__, 'is_imported_from_identity_provider'),
        is_password_expired=pulumi.get(__ret__, 'is_password_expired'),
        is_two_factor_auth_enabled=pulumi.get(__ret__, 'is_two_factor_auth_enabled'),
        is_user_locked=pulumi.get(__ret__, 'is_user_locked'),
        name=pulumi.get(__ret__, 'name'))
def get_user_output(email: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserResult]:
    """
    Data source for retrieving a Harness user


    :param _builtins.str email: The email of the user.
    :param _builtins.str id: Unique identifier of the user
    """
    __args__ = dict()
    __args__['email'] = email
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:index/getUser:getUser', __args__, opts=opts, typ=GetUserResult)
    return __ret__.apply(lambda __response__: GetUserResult(
        email=pulumi.get(__response__, 'email'),
        id=pulumi.get(__response__, 'id'),
        is_email_verified=pulumi.get(__response__, 'is_email_verified'),
        is_imported_from_identity_provider=pulumi.get(__response__, 'is_imported_from_identity_provider'),
        is_password_expired=pulumi.get(__response__, 'is_password_expired'),
        is_two_factor_auth_enabled=pulumi.get(__response__, 'is_two_factor_auth_enabled'),
        is_user_locked=pulumi.get(__response__, 'is_user_locked'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetGitopsApplicationsResult',
    'AwaitableGetGitopsApplicationsResult',
    'get_gitops_applications',
    'get_gitops_applications_output',
]

@pulumi.output_type
class GetGitopsApplicationsResult:
    """
    A collection of values returned by getGitopsApplications.
    """
    def __init__(__self__, account_id=None, agent_id=None, applications=None, cluster_id=None, id=None, identifier=None, kind=None, name=None, options_remove_existing_finalizers=None, org_id=None, project=None, project_id=None, repo_id=None, repo_ids=None, request_cascade=None, request_propagation_policy=None, skip_repo_validation=None, upsert=None, validate=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if agent_id and not isinstance(agent_id, str):
            raise TypeError("Expected argument 'agent_id' to be a str")
        pulumi.set(__self__, "agent_id", agent_id)
        if applications and not isinstance(applications, list):
            raise TypeError("Expected argument 'applications' to be a list")
        pulumi.set(__self__, "applications", applications)
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        pulumi.set(__self__, "kind", kind)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if options_remove_existing_finalizers and not isinstance(options_remove_existing_finalizers, bool):
            raise TypeError("Expected argument 'options_remove_existing_finalizers' to be a bool")
        pulumi.set(__self__, "options_remove_existing_finalizers", options_remove_existing_finalizers)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if repo_id and not isinstance(repo_id, str):
            raise TypeError("Expected argument 'repo_id' to be a str")
        pulumi.set(__self__, "repo_id", repo_id)
        if repo_ids and not isinstance(repo_ids, list):
            raise TypeError("Expected argument 'repo_ids' to be a list")
        pulumi.set(__self__, "repo_ids", repo_ids)
        if request_cascade and not isinstance(request_cascade, bool):
            raise TypeError("Expected argument 'request_cascade' to be a bool")
        pulumi.set(__self__, "request_cascade", request_cascade)
        if request_propagation_policy and not isinstance(request_propagation_policy, str):
            raise TypeError("Expected argument 'request_propagation_policy' to be a str")
        pulumi.set(__self__, "request_propagation_policy", request_propagation_policy)
        if skip_repo_validation and not isinstance(skip_repo_validation, bool):
            raise TypeError("Expected argument 'skip_repo_validation' to be a bool")
        pulumi.set(__self__, "skip_repo_validation", skip_repo_validation)
        if upsert and not isinstance(upsert, bool):
            raise TypeError("Expected argument 'upsert' to be a bool")
        pulumi.set(__self__, "upsert", upsert)
        if validate and not isinstance(validate, bool):
            raise TypeError("Expected argument 'validate' to be a bool")
        pulumi.set(__self__, "validate", validate)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> _builtins.str:
        """
        Account identifier of the GitOps application.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> _builtins.str:
        """
        Agent identifier of the GitOps application.
        """
        return pulumi.get(self, "agent_id")

    @_builtins.property
    @pulumi.getter
    def applications(self) -> Sequence['outputs.GetGitopsApplicationsApplicationResult']:
        """
        Definition of the GitOps application resource.
        """
        return pulumi.get(self, "applications")

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> _builtins.str:
        """
        Cluster identifier of the GitOps application.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def identifier(self) -> Optional[_builtins.str]:
        """
        Identifier of the GitOps application.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> _builtins.str:
        """
        Kind of the GitOps application.
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the GitOps application.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="optionsRemoveExistingFinalizers")
    def options_remove_existing_finalizers(self) -> _builtins.bool:
        """
        Options to remove existing finalizers to delete the GitOps application.
        """
        return pulumi.get(self, "options_remove_existing_finalizers")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        Organization identifier of the GitOps application.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        The ArgoCD project name corresponding to this GitOps application. An empty string means that the GitOps application belongs to the default project created by Harness.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        Project identifier of the GitOps application.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="repoId")
    def repo_id(self) -> _builtins.str:
        """
        Repository identifier of the GitOps application.
        """
        return pulumi.get(self, "repo_id")

    @_builtins.property
    @pulumi.getter(name="repoIds")
    def repo_ids(self) -> Sequence[_builtins.str]:
        """
        List of repository identifiers of the GitOps for Multi-Source application. Not required if skipRepoValidation is set to true.
        """
        return pulumi.get(self, "repo_ids")

    @_builtins.property
    @pulumi.getter(name="requestCascade")
    def request_cascade(self) -> _builtins.bool:
        """
        Request cascade to delete the GitOps application.
        """
        return pulumi.get(self, "request_cascade")

    @_builtins.property
    @pulumi.getter(name="requestPropagationPolicy")
    def request_propagation_policy(self) -> _builtins.str:
        """
        Request propagation policy to delete the GitOps application.
        """
        return pulumi.get(self, "request_propagation_policy")

    @_builtins.property
    @pulumi.getter(name="skipRepoValidation")
    def skip_repo_validation(self) -> _builtins.bool:
        """
        Indicates if the GitOps application should skip validate repository definition exists.
        """
        return pulumi.get(self, "skip_repo_validation")

    @_builtins.property
    @pulumi.getter
    def upsert(self) -> _builtins.bool:
        """
        Indicates if the GitOps application should be updated if existing and inserted if not.
        """
        return pulumi.get(self, "upsert")

    @_builtins.property
    @pulumi.getter
    def validate(self) -> _builtins.bool:
        """
        Indicates if the GitOps application yaml has to be validated.
        """
        return pulumi.get(self, "validate")


class AwaitableGetGitopsApplicationsResult(GetGitopsApplicationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGitopsApplicationsResult(
            account_id=self.account_id,
            agent_id=self.agent_id,
            applications=self.applications,
            cluster_id=self.cluster_id,
            id=self.id,
            identifier=self.identifier,
            kind=self.kind,
            name=self.name,
            options_remove_existing_finalizers=self.options_remove_existing_finalizers,
            org_id=self.org_id,
            project=self.project,
            project_id=self.project_id,
            repo_id=self.repo_id,
            repo_ids=self.repo_ids,
            request_cascade=self.request_cascade,
            request_propagation_policy=self.request_propagation_policy,
            skip_repo_validation=self.skip_repo_validation,
            upsert=self.upsert,
            validate=self.validate)


def get_gitops_applications(account_id: Optional[_builtins.str] = None,
                            agent_id: Optional[_builtins.str] = None,
                            identifier: Optional[_builtins.str] = None,
                            name: Optional[_builtins.str] = None,
                            org_id: Optional[_builtins.str] = None,
                            project_id: Optional[_builtins.str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGitopsApplicationsResult:
    """
    Datasource for fetching a Harness GitOps Application.

    ## Example Usage


    :param _builtins.str account_id: Account identifier of the GitOps application.
    :param _builtins.str agent_id: Agent identifier of the GitOps application.
    :param _builtins.str identifier: Identifier of the GitOps application.
    :param _builtins.str name: Name of the GitOps application.
    :param _builtins.str org_id: Organization identifier of the GitOps application.
    :param _builtins.str project_id: Project identifier of the GitOps application.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['agentId'] = agent_id
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getGitopsApplications:getGitopsApplications', __args__, opts=opts, typ=GetGitopsApplicationsResult).value

    return AwaitableGetGitopsApplicationsResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        agent_id=pulumi.get(__ret__, 'agent_id'),
        applications=pulumi.get(__ret__, 'applications'),
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        kind=pulumi.get(__ret__, 'kind'),
        name=pulumi.get(__ret__, 'name'),
        options_remove_existing_finalizers=pulumi.get(__ret__, 'options_remove_existing_finalizers'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project=pulumi.get(__ret__, 'project'),
        project_id=pulumi.get(__ret__, 'project_id'),
        repo_id=pulumi.get(__ret__, 'repo_id'),
        repo_ids=pulumi.get(__ret__, 'repo_ids'),
        request_cascade=pulumi.get(__ret__, 'request_cascade'),
        request_propagation_policy=pulumi.get(__ret__, 'request_propagation_policy'),
        skip_repo_validation=pulumi.get(__ret__, 'skip_repo_validation'),
        upsert=pulumi.get(__ret__, 'upsert'),
        validate=pulumi.get(__ret__, 'validate'))
def get_gitops_applications_output(account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                                   identifier: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   name: Optional[pulumi.Input[_builtins.str]] = None,
                                   org_id: Optional[pulumi.Input[_builtins.str]] = None,
                                   project_id: Optional[pulumi.Input[_builtins.str]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGitopsApplicationsResult]:
    """
    Datasource for fetching a Harness GitOps Application.

    ## Example Usage


    :param _builtins.str account_id: Account identifier of the GitOps application.
    :param _builtins.str agent_id: Agent identifier of the GitOps application.
    :param _builtins.str identifier: Identifier of the GitOps application.
    :param _builtins.str name: Name of the GitOps application.
    :param _builtins.str org_id: Organization identifier of the GitOps application.
    :param _builtins.str project_id: Project identifier of the GitOps application.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['agentId'] = agent_id
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getGitopsApplications:getGitopsApplications', __args__, opts=opts, typ=GetGitopsApplicationsResult)
    return __ret__.apply(lambda __response__: GetGitopsApplicationsResult(
        account_id=pulumi.get(__response__, 'account_id'),
        agent_id=pulumi.get(__response__, 'agent_id'),
        applications=pulumi.get(__response__, 'applications'),
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        kind=pulumi.get(__response__, 'kind'),
        name=pulumi.get(__response__, 'name'),
        options_remove_existing_finalizers=pulumi.get(__response__, 'options_remove_existing_finalizers'),
        org_id=pulumi.get(__response__, 'org_id'),
        project=pulumi.get(__response__, 'project'),
        project_id=pulumi.get(__response__, 'project_id'),
        repo_id=pulumi.get(__response__, 'repo_id'),
        repo_ids=pulumi.get(__response__, 'repo_ids'),
        request_cascade=pulumi.get(__response__, 'request_cascade'),
        request_propagation_policy=pulumi.get(__response__, 'request_propagation_policy'),
        skip_repo_validation=pulumi.get(__response__, 'skip_repo_validation'),
        upsert=pulumi.get(__response__, 'upsert'),
        validate=pulumi.get(__response__, 'validate')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAzureCloudProviderConnectorResult',
    'AwaitableGetAzureCloudProviderConnectorResult',
    'get_azure_cloud_provider_connector',
    'get_azure_cloud_provider_connector_output',
]

@pulumi.output_type
class GetAzureCloudProviderConnectorResult:
    """
    A collection of values returned by getAzureCloudProviderConnector.
    """
    def __init__(__self__, azure_environment_type=None, credentials=None, delegate_selectors=None, description=None, execute_on_delegate=None, id=None, identifier=None, name=None, org_id=None, project_id=None, tags=None):
        if azure_environment_type and not isinstance(azure_environment_type, str):
            raise TypeError("Expected argument 'azure_environment_type' to be a str")
        pulumi.set(__self__, "azure_environment_type", azure_environment_type)
        if credentials and not isinstance(credentials, list):
            raise TypeError("Expected argument 'credentials' to be a list")
        pulumi.set(__self__, "credentials", credentials)
        if delegate_selectors and not isinstance(delegate_selectors, list):
            raise TypeError("Expected argument 'delegate_selectors' to be a list")
        pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if execute_on_delegate and not isinstance(execute_on_delegate, bool):
            raise TypeError("Expected argument 'execute_on_delegate' to be a bool")
        pulumi.set(__self__, "execute_on_delegate", execute_on_delegate)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="azureEnvironmentType")
    def azure_environment_type(self) -> _builtins.str:
        """
        Specifies the Azure Environment type, which is AZURE by default. Can either be AZURE or AZURE*US*GOVERNMENT
        """
        return pulumi.get(self, "azure_environment_type")

    @_builtins.property
    @pulumi.getter
    def credentials(self) -> Sequence['outputs.GetAzureCloudProviderConnectorCredentialResult']:
        """
        Contains Azure connector credentials.
        """
        return pulumi.get(self, "credentials")

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Sequence[_builtins.str]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="executeOnDelegate")
    def execute_on_delegate(self) -> _builtins.bool:
        """
        Execute on delegate or not.
        """
        return pulumi.get(self, "execute_on_delegate")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetAzureCloudProviderConnectorResult(GetAzureCloudProviderConnectorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAzureCloudProviderConnectorResult(
            azure_environment_type=self.azure_environment_type,
            credentials=self.credentials,
            delegate_selectors=self.delegate_selectors,
            description=self.description,
            execute_on_delegate=self.execute_on_delegate,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            tags=self.tags)


def get_azure_cloud_provider_connector(identifier: Optional[_builtins.str] = None,
                                       name: Optional[_builtins.str] = None,
                                       org_id: Optional[_builtins.str] = None,
                                       project_id: Optional[_builtins.str] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAzureCloudProviderConnectorResult:
    """
    Datasource for looking up an Azure Cloud Provider Connector.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_azure_cloud_provider_connector(identifier="identifier")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getAzureCloudProviderConnector:getAzureCloudProviderConnector', __args__, opts=opts, typ=GetAzureCloudProviderConnectorResult).value

    return AwaitableGetAzureCloudProviderConnectorResult(
        azure_environment_type=pulumi.get(__ret__, 'azure_environment_type'),
        credentials=pulumi.get(__ret__, 'credentials'),
        delegate_selectors=pulumi.get(__ret__, 'delegate_selectors'),
        description=pulumi.get(__ret__, 'description'),
        execute_on_delegate=pulumi.get(__ret__, 'execute_on_delegate'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_azure_cloud_provider_connector_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                              name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                              org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                              project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAzureCloudProviderConnectorResult]:
    """
    Datasource for looking up an Azure Cloud Provider Connector.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_azure_cloud_provider_connector(identifier="identifier")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getAzureCloudProviderConnector:getAzureCloudProviderConnector', __args__, opts=opts, typ=GetAzureCloudProviderConnectorResult)
    return __ret__.apply(lambda __response__: GetAzureCloudProviderConnectorResult(
        azure_environment_type=pulumi.get(__response__, 'azure_environment_type'),
        credentials=pulumi.get(__response__, 'credentials'),
        delegate_selectors=pulumi.get(__response__, 'delegate_selectors'),
        description=pulumi.get(__response__, 'description'),
        execute_on_delegate=pulumi.get(__response__, 'execute_on_delegate'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FeatureFlagApiKeyArgs', 'FeatureFlagApiKey']

@pulumi.input_type
class FeatureFlagApiKeyArgs:
    def __init__(__self__, *,
                 env_id: pulumi.Input[_builtins.str],
                 identifier: pulumi.Input[_builtins.str],
                 org_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 expired_at: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a FeatureFlagApiKey resource.
        :param pulumi.Input[_builtins.str] env_id: Environment Identifier
        :param pulumi.Input[_builtins.str] identifier: Identifier of the SDK API Key
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier
        :param pulumi.Input[_builtins.str] project_id: Project Identifier
        :param pulumi.Input[_builtins.str] type: Type of SDK. Valid values are `Server` or `Client`.
        :param pulumi.Input[_builtins.str] description: Description of the SDK API Key
        :param pulumi.Input[_builtins.int] expired_at: Expiration datetime of the SDK API Key
        :param pulumi.Input[_builtins.str] name: Name of the SDK API Key
        """
        pulumi.set(__self__, "env_id", env_id)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "type", type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if expired_at is not None:
            pulumi.set(__self__, "expired_at", expired_at)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="envId")
    def env_id(self) -> pulumi.Input[_builtins.str]:
        """
        Environment Identifier
        """
        return pulumi.get(self, "env_id")

    @env_id.setter
    def env_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "env_id", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the SDK API Key
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        Organization Identifier
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Project Identifier
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of SDK. Valid values are `Server` or `Client`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the SDK API Key
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="expiredAt")
    def expired_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Expiration datetime of the SDK API Key
        """
        return pulumi.get(self, "expired_at")

    @expired_at.setter
    def expired_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "expired_at", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the SDK API Key
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _FeatureFlagApiKeyState:
    def __init__(__self__, *,
                 api_key: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 env_id: Optional[pulumi.Input[_builtins.str]] = None,
                 expired_at: Optional[pulumi.Input[_builtins.int]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering FeatureFlagApiKey resources.
        :param pulumi.Input[_builtins.str] api_key: The value of the SDK API Key
        :param pulumi.Input[_builtins.str] description: Description of the SDK API Key
        :param pulumi.Input[_builtins.str] env_id: Environment Identifier
        :param pulumi.Input[_builtins.int] expired_at: Expiration datetime of the SDK API Key
        :param pulumi.Input[_builtins.str] identifier: Identifier of the SDK API Key
        :param pulumi.Input[_builtins.str] name: Name of the SDK API Key
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier
        :param pulumi.Input[_builtins.str] project_id: Project Identifier
        :param pulumi.Input[_builtins.str] type: Type of SDK. Valid values are `Server` or `Client`.
        """
        if api_key is not None:
            pulumi.set(__self__, "api_key", api_key)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if env_id is not None:
            pulumi.set(__self__, "env_id", env_id)
        if expired_at is not None:
            pulumi.set(__self__, "expired_at", expired_at)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value of the SDK API Key
        """
        return pulumi.get(self, "api_key")

    @api_key.setter
    def api_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_key", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the SDK API Key
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="envId")
    def env_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Environment Identifier
        """
        return pulumi.get(self, "env_id")

    @env_id.setter
    def env_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "env_id", value)

    @_builtins.property
    @pulumi.getter(name="expiredAt")
    def expired_at(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Expiration datetime of the SDK API Key
        """
        return pulumi.get(self, "expired_at")

    @expired_at.setter
    def expired_at(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "expired_at", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the SDK API Key
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the SDK API Key
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Organization Identifier
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project Identifier
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of SDK. Valid values are `Server` or `Client`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("harness:platform/featureFlagApiKey:FeatureFlagApiKey")
class FeatureFlagApiKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 env_id: Optional[pulumi.Input[_builtins.str]] = None,
                 expired_at: Optional[pulumi.Input[_builtins.int]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating an environment SDK key for Feature Flags.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        testserverapikey = harness.platform.FeatureFlagApiKey("testserverapikey",
            identifier="testserver",
            name="TestServer",
            description="this is a server SDK key",
            org_id="test",
            project_id="testff",
            env_id="testenv",
            expired_at=1713729225,
            type="Server")
        pulumi.export("serversdkkey", testserverapikey.api_key)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the SDK API Key
        :param pulumi.Input[_builtins.str] env_id: Environment Identifier
        :param pulumi.Input[_builtins.int] expired_at: Expiration datetime of the SDK API Key
        :param pulumi.Input[_builtins.str] identifier: Identifier of the SDK API Key
        :param pulumi.Input[_builtins.str] name: Name of the SDK API Key
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier
        :param pulumi.Input[_builtins.str] project_id: Project Identifier
        :param pulumi.Input[_builtins.str] type: Type of SDK. Valid values are `Server` or `Client`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FeatureFlagApiKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating an environment SDK key for Feature Flags.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        testserverapikey = harness.platform.FeatureFlagApiKey("testserverapikey",
            identifier="testserver",
            name="TestServer",
            description="this is a server SDK key",
            org_id="test",
            project_id="testff",
            env_id="testenv",
            expired_at=1713729225,
            type="Server")
        pulumi.export("serversdkkey", testserverapikey.api_key)
        ```

        :param str resource_name: The name of the resource.
        :param FeatureFlagApiKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FeatureFlagApiKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 env_id: Optional[pulumi.Input[_builtins.str]] = None,
                 expired_at: Optional[pulumi.Input[_builtins.int]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FeatureFlagApiKeyArgs.__new__(FeatureFlagApiKeyArgs)

            __props__.__dict__["description"] = description
            if env_id is None and not opts.urn:
                raise TypeError("Missing required property 'env_id'")
            __props__.__dict__["env_id"] = env_id
            __props__.__dict__["expired_at"] = expired_at
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["api_key"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["apiKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(FeatureFlagApiKey, __self__).__init__(
            'harness:platform/featureFlagApiKey:FeatureFlagApiKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_key: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            env_id: Optional[pulumi.Input[_builtins.str]] = None,
            expired_at: Optional[pulumi.Input[_builtins.int]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'FeatureFlagApiKey':
        """
        Get an existing FeatureFlagApiKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_key: The value of the SDK API Key
        :param pulumi.Input[_builtins.str] description: Description of the SDK API Key
        :param pulumi.Input[_builtins.str] env_id: Environment Identifier
        :param pulumi.Input[_builtins.int] expired_at: Expiration datetime of the SDK API Key
        :param pulumi.Input[_builtins.str] identifier: Identifier of the SDK API Key
        :param pulumi.Input[_builtins.str] name: Name of the SDK API Key
        :param pulumi.Input[_builtins.str] org_id: Organization Identifier
        :param pulumi.Input[_builtins.str] project_id: Project Identifier
        :param pulumi.Input[_builtins.str] type: Type of SDK. Valid values are `Server` or `Client`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FeatureFlagApiKeyState.__new__(_FeatureFlagApiKeyState)

        __props__.__dict__["api_key"] = api_key
        __props__.__dict__["description"] = description
        __props__.__dict__["env_id"] = env_id
        __props__.__dict__["expired_at"] = expired_at
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["type"] = type
        return FeatureFlagApiKey(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="apiKey")
    def api_key(self) -> pulumi.Output[_builtins.str]:
        """
        The value of the SDK API Key
        """
        return pulumi.get(self, "api_key")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the SDK API Key
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="envId")
    def env_id(self) -> pulumi.Output[_builtins.str]:
        """
        Environment Identifier
        """
        return pulumi.get(self, "env_id")

    @_builtins.property
    @pulumi.getter(name="expiredAt")
    def expired_at(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Expiration datetime of the SDK API Key
        """
        return pulumi.get(self, "expired_at")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the SDK API Key
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the SDK API Key
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        Organization Identifier
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Project Identifier
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of SDK. Valid values are `Server` or `Client`.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAwsConnectorResult',
    'AwaitableGetAwsConnectorResult',
    'get_aws_connector',
    'get_aws_connector_output',
]

@pulumi.output_type
class GetAwsConnectorResult:
    """
    A collection of values returned by getAwsConnector.
    """
    def __init__(__self__, cross_account_accesses=None, description=None, equal_jitter_backoff_strategies=None, execute_on_delegate=None, fixed_delay_backoff_strategies=None, full_jitter_backoff_strategies=None, id=None, identifier=None, inherit_from_delegates=None, irsas=None, manuals=None, name=None, oidc_authentications=None, org_id=None, project_id=None, tags=None):
        if cross_account_accesses and not isinstance(cross_account_accesses, list):
            raise TypeError("Expected argument 'cross_account_accesses' to be a list")
        pulumi.set(__self__, "cross_account_accesses", cross_account_accesses)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if equal_jitter_backoff_strategies and not isinstance(equal_jitter_backoff_strategies, list):
            raise TypeError("Expected argument 'equal_jitter_backoff_strategies' to be a list")
        pulumi.set(__self__, "equal_jitter_backoff_strategies", equal_jitter_backoff_strategies)
        if execute_on_delegate and not isinstance(execute_on_delegate, bool):
            raise TypeError("Expected argument 'execute_on_delegate' to be a bool")
        pulumi.set(__self__, "execute_on_delegate", execute_on_delegate)
        if fixed_delay_backoff_strategies and not isinstance(fixed_delay_backoff_strategies, list):
            raise TypeError("Expected argument 'fixed_delay_backoff_strategies' to be a list")
        pulumi.set(__self__, "fixed_delay_backoff_strategies", fixed_delay_backoff_strategies)
        if full_jitter_backoff_strategies and not isinstance(full_jitter_backoff_strategies, list):
            raise TypeError("Expected argument 'full_jitter_backoff_strategies' to be a list")
        pulumi.set(__self__, "full_jitter_backoff_strategies", full_jitter_backoff_strategies)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if inherit_from_delegates and not isinstance(inherit_from_delegates, list):
            raise TypeError("Expected argument 'inherit_from_delegates' to be a list")
        pulumi.set(__self__, "inherit_from_delegates", inherit_from_delegates)
        if irsas and not isinstance(irsas, list):
            raise TypeError("Expected argument 'irsas' to be a list")
        pulumi.set(__self__, "irsas", irsas)
        if manuals and not isinstance(manuals, list):
            raise TypeError("Expected argument 'manuals' to be a list")
        pulumi.set(__self__, "manuals", manuals)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if oidc_authentications and not isinstance(oidc_authentications, list):
            raise TypeError("Expected argument 'oidc_authentications' to be a list")
        pulumi.set(__self__, "oidc_authentications", oidc_authentications)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="crossAccountAccesses")
    def cross_account_accesses(self) -> Sequence['outputs.GetAwsConnectorCrossAccountAccessResult']:
        """
        Select this option if you want to use one AWS account for the connection, but you want to deploy or build in a different AWS account. In this scenario, the AWS account used for AWS access in Credentials will assume the IAM role you specify in Cross-account role ARN setting. This option uses the AWS Security Token Service (STS) feature.
        """
        return pulumi.get(self, "cross_account_accesses")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="equalJitterBackoffStrategies")
    def equal_jitter_backoff_strategies(self) -> Sequence['outputs.GetAwsConnectorEqualJitterBackoffStrategyResult']:
        """
        Equal Jitter BackOff Strategy.
        """
        return pulumi.get(self, "equal_jitter_backoff_strategies")

    @_builtins.property
    @pulumi.getter(name="executeOnDelegate")
    def execute_on_delegate(self) -> _builtins.bool:
        """
        Execute on delegate or not.
        """
        return pulumi.get(self, "execute_on_delegate")

    @_builtins.property
    @pulumi.getter(name="fixedDelayBackoffStrategies")
    def fixed_delay_backoff_strategies(self) -> Sequence['outputs.GetAwsConnectorFixedDelayBackoffStrategyResult']:
        """
        Fixed Delay BackOff Strategy.
        """
        return pulumi.get(self, "fixed_delay_backoff_strategies")

    @_builtins.property
    @pulumi.getter(name="fullJitterBackoffStrategies")
    def full_jitter_backoff_strategies(self) -> Sequence['outputs.GetAwsConnectorFullJitterBackoffStrategyResult']:
        """
        Full Jitter BackOff Strategy.
        """
        return pulumi.get(self, "full_jitter_backoff_strategies")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="inheritFromDelegates")
    def inherit_from_delegates(self) -> Sequence['outputs.GetAwsConnectorInheritFromDelegateResult']:
        """
        Inherit credentials from the delegate.
        """
        return pulumi.get(self, "inherit_from_delegates")

    @_builtins.property
    @pulumi.getter
    def irsas(self) -> Sequence['outputs.GetAwsConnectorIrsaResult']:
        """
        Use IAM role for service accounts.
        """
        return pulumi.get(self, "irsas")

    @_builtins.property
    @pulumi.getter
    def manuals(self) -> Sequence['outputs.GetAwsConnectorManualResult']:
        """
        Use IAM role for service accounts.
        """
        return pulumi.get(self, "manuals")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="oidcAuthentications")
    def oidc_authentications(self) -> Sequence['outputs.GetAwsConnectorOidcAuthenticationResult']:
        """
        Authentication using harness oidc.
        """
        return pulumi.get(self, "oidc_authentications")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetAwsConnectorResult(GetAwsConnectorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAwsConnectorResult(
            cross_account_accesses=self.cross_account_accesses,
            description=self.description,
            equal_jitter_backoff_strategies=self.equal_jitter_backoff_strategies,
            execute_on_delegate=self.execute_on_delegate,
            fixed_delay_backoff_strategies=self.fixed_delay_backoff_strategies,
            full_jitter_backoff_strategies=self.full_jitter_backoff_strategies,
            id=self.id,
            identifier=self.identifier,
            inherit_from_delegates=self.inherit_from_delegates,
            irsas=self.irsas,
            manuals=self.manuals,
            name=self.name,
            oidc_authentications=self.oidc_authentications,
            org_id=self.org_id,
            project_id=self.project_id,
            tags=self.tags)


def get_aws_connector(identifier: Optional[_builtins.str] = None,
                      name: Optional[_builtins.str] = None,
                      org_id: Optional[_builtins.str] = None,
                      project_id: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAwsConnectorResult:
    """
    Datasource for looking up an AWS connector.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_aws_connector(identifier="identifier")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getAwsConnector:getAwsConnector', __args__, opts=opts, typ=GetAwsConnectorResult).value

    return AwaitableGetAwsConnectorResult(
        cross_account_accesses=pulumi.get(__ret__, 'cross_account_accesses'),
        description=pulumi.get(__ret__, 'description'),
        equal_jitter_backoff_strategies=pulumi.get(__ret__, 'equal_jitter_backoff_strategies'),
        execute_on_delegate=pulumi.get(__ret__, 'execute_on_delegate'),
        fixed_delay_backoff_strategies=pulumi.get(__ret__, 'fixed_delay_backoff_strategies'),
        full_jitter_backoff_strategies=pulumi.get(__ret__, 'full_jitter_backoff_strategies'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        inherit_from_delegates=pulumi.get(__ret__, 'inherit_from_delegates'),
        irsas=pulumi.get(__ret__, 'irsas'),
        manuals=pulumi.get(__ret__, 'manuals'),
        name=pulumi.get(__ret__, 'name'),
        oidc_authentications=pulumi.get(__ret__, 'oidc_authentications'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_aws_connector_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                             name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAwsConnectorResult]:
    """
    Datasource for looking up an AWS connector.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_aws_connector(identifier="identifier")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getAwsConnector:getAwsConnector', __args__, opts=opts, typ=GetAwsConnectorResult)
    return __ret__.apply(lambda __response__: GetAwsConnectorResult(
        cross_account_accesses=pulumi.get(__response__, 'cross_account_accesses'),
        description=pulumi.get(__response__, 'description'),
        equal_jitter_backoff_strategies=pulumi.get(__response__, 'equal_jitter_backoff_strategies'),
        execute_on_delegate=pulumi.get(__response__, 'execute_on_delegate'),
        fixed_delay_backoff_strategies=pulumi.get(__response__, 'fixed_delay_backoff_strategies'),
        full_jitter_backoff_strategies=pulumi.get(__response__, 'full_jitter_backoff_strategies'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        inherit_from_delegates=pulumi.get(__response__, 'inherit_from_delegates'),
        irsas=pulumi.get(__response__, 'irsas'),
        manuals=pulumi.get(__response__, 'manuals'),
        name=pulumi.get(__response__, 'name'),
        oidc_authentications=pulumi.get(__response__, 'oidc_authentications'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetProviderResult',
    'AwaitableGetProviderResult',
    'get_provider',
    'get_provider_output',
]

@pulumi.output_type
class GetProviderResult:
    """
    A collection of values returned by getProvider.
    """
    def __init__(__self__, id=None, identifier=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        The identifier of the provider entity.
        """
        return pulumi.get(self, "identifier")


class AwaitableGetProviderResult(GetProviderResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProviderResult(
            id=self.id,
            identifier=self.identifier)


def get_provider(identifier: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProviderResult:
    """
    Data source for Harness Provider.


    :param _builtins.str identifier: The identifier of the provider entity.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getProvider:getProvider', __args__, opts=opts, typ=GetProviderResult).value

    return AwaitableGetProviderResult(
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'))
def get_provider_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProviderResult]:
    """
    Data source for Harness Provider.


    :param _builtins.str identifier: The identifier of the provider entity.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getProvider:getProvider', __args__, opts=opts, typ=GetProviderResult)
    return __ret__.apply(lambda __response__: GetProviderResult(
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCentralNotificationRuleResult',
    'AwaitableGetCentralNotificationRuleResult',
    'get_central_notification_rule',
    'get_central_notification_rule_output',
]

@pulumi.output_type
class GetCentralNotificationRuleResult:
    """
    A collection of values returned by getCentralNotificationRule.
    """
    def __init__(__self__, account=None, created=None, custom_notification_template_ref=None, id=None, identifier=None, last_modified=None, name=None, notification_channel_refs=None, notification_conditions=None, org=None, project=None, status=None):
        if account and not isinstance(account, str):
            raise TypeError("Expected argument 'account' to be a str")
        pulumi.set(__self__, "account", account)
        if created and not isinstance(created, int):
            raise TypeError("Expected argument 'created' to be a int")
        pulumi.set(__self__, "created", created)
        if custom_notification_template_ref and not isinstance(custom_notification_template_ref, dict):
            raise TypeError("Expected argument 'custom_notification_template_ref' to be a dict")
        pulumi.set(__self__, "custom_notification_template_ref", custom_notification_template_ref)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if last_modified and not isinstance(last_modified, int):
            raise TypeError("Expected argument 'last_modified' to be a int")
        pulumi.set(__self__, "last_modified", last_modified)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if notification_channel_refs and not isinstance(notification_channel_refs, list):
            raise TypeError("Expected argument 'notification_channel_refs' to be a list")
        pulumi.set(__self__, "notification_channel_refs", notification_channel_refs)
        if notification_conditions and not isinstance(notification_conditions, list):
            raise TypeError("Expected argument 'notification_conditions' to be a list")
        pulumi.set(__self__, "notification_conditions", notification_conditions)
        if org and not isinstance(org, str):
            raise TypeError("Expected argument 'org' to be a str")
        pulumi.set(__self__, "org", org)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def account(self) -> _builtins.str:
        """
        Account identifier associated with this notification channel.
        """
        return pulumi.get(self, "account")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.int:
        """
        Timestamp when the notification rule was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="customNotificationTemplateRef")
    def custom_notification_template_ref(self) -> Optional['outputs.GetCentralNotificationRuleCustomNotificationTemplateRefResult']:
        return pulumi.get(self, "custom_notification_template_ref")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the Notification Rule.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="lastModified")
    def last_modified(self) -> _builtins.int:
        """
        Timestamp when the notification rule was last modified.
        """
        return pulumi.get(self, "last_modified")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notificationChannelRefs")
    def notification_channel_refs(self) -> Optional[Sequence[_builtins.str]]:
        return pulumi.get(self, "notification_channel_refs")

    @_builtins.property
    @pulumi.getter(name="notificationConditions")
    def notification_conditions(self) -> Optional[Sequence['outputs.GetCentralNotificationRuleNotificationConditionResult']]:
        return pulumi.get(self, "notification_conditions")

    @_builtins.property
    @pulumi.getter
    def org(self) -> Optional[_builtins.str]:
        """
        Identifier of the organization in which the Notification Rule is configured.
        """
        return pulumi.get(self, "org")

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[_builtins.str]:
        """
        Identifier of the project in which the Notification Rule is configured.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "status")


class AwaitableGetCentralNotificationRuleResult(GetCentralNotificationRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCentralNotificationRuleResult(
            account=self.account,
            created=self.created,
            custom_notification_template_ref=self.custom_notification_template_ref,
            id=self.id,
            identifier=self.identifier,
            last_modified=self.last_modified,
            name=self.name,
            notification_channel_refs=self.notification_channel_refs,
            notification_conditions=self.notification_conditions,
            org=self.org,
            project=self.project,
            status=self.status)


def get_central_notification_rule(custom_notification_template_ref: Optional[Union['GetCentralNotificationRuleCustomNotificationTemplateRefArgs', 'GetCentralNotificationRuleCustomNotificationTemplateRefArgsDict']] = None,
                                  identifier: Optional[_builtins.str] = None,
                                  name: Optional[_builtins.str] = None,
                                  notification_channel_refs: Optional[Sequence[_builtins.str]] = None,
                                  notification_conditions: Optional[Sequence[Union['GetCentralNotificationRuleNotificationConditionArgs', 'GetCentralNotificationRuleNotificationConditionArgsDict']]] = None,
                                  org: Optional[_builtins.str] = None,
                                  project: Optional[_builtins.str] = None,
                                  status: Optional[_builtins.str] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCentralNotificationRuleResult:
    """
    > Deprecated: Please use `data.harness_platform_pipeline_central_notification_rule`. See the pipeline-specific data source docs.

    Data source for retrieving a Notification Rule.


    :param _builtins.str identifier: Identifier of the Notification Rule.
    :param _builtins.str org: Identifier of the organization in which the Notification Rule is configured.
    :param _builtins.str project: Identifier of the project in which the Notification Rule is configured.
    """
    __args__ = dict()
    __args__['customNotificationTemplateRef'] = custom_notification_template_ref
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['notificationChannelRefs'] = notification_channel_refs
    __args__['notificationConditions'] = notification_conditions
    __args__['org'] = org
    __args__['project'] = project
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getCentralNotificationRule:getCentralNotificationRule', __args__, opts=opts, typ=GetCentralNotificationRuleResult).value

    return AwaitableGetCentralNotificationRuleResult(
        account=pulumi.get(__ret__, 'account'),
        created=pulumi.get(__ret__, 'created'),
        custom_notification_template_ref=pulumi.get(__ret__, 'custom_notification_template_ref'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        last_modified=pulumi.get(__ret__, 'last_modified'),
        name=pulumi.get(__ret__, 'name'),
        notification_channel_refs=pulumi.get(__ret__, 'notification_channel_refs'),
        notification_conditions=pulumi.get(__ret__, 'notification_conditions'),
        org=pulumi.get(__ret__, 'org'),
        project=pulumi.get(__ret__, 'project'),
        status=pulumi.get(__ret__, 'status'))
def get_central_notification_rule_output(custom_notification_template_ref: Optional[pulumi.Input[Optional[Union['GetCentralNotificationRuleCustomNotificationTemplateRefArgs', 'GetCentralNotificationRuleCustomNotificationTemplateRefArgsDict']]]] = None,
                                         identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                         name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                         notification_channel_refs: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                                         notification_conditions: Optional[pulumi.Input[Optional[Sequence[Union['GetCentralNotificationRuleNotificationConditionArgs', 'GetCentralNotificationRuleNotificationConditionArgsDict']]]]] = None,
                                         org: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                         project: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                         status: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCentralNotificationRuleResult]:
    """
    > Deprecated: Please use `data.harness_platform_pipeline_central_notification_rule`. See the pipeline-specific data source docs.

    Data source for retrieving a Notification Rule.


    :param _builtins.str identifier: Identifier of the Notification Rule.
    :param _builtins.str org: Identifier of the organization in which the Notification Rule is configured.
    :param _builtins.str project: Identifier of the project in which the Notification Rule is configured.
    """
    __args__ = dict()
    __args__['customNotificationTemplateRef'] = custom_notification_template_ref
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['notificationChannelRefs'] = notification_channel_refs
    __args__['notificationConditions'] = notification_conditions
    __args__['org'] = org
    __args__['project'] = project
    __args__['status'] = status
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getCentralNotificationRule:getCentralNotificationRule', __args__, opts=opts, typ=GetCentralNotificationRuleResult)
    return __ret__.apply(lambda __response__: GetCentralNotificationRuleResult(
        account=pulumi.get(__response__, 'account'),
        created=pulumi.get(__response__, 'created'),
        custom_notification_template_ref=pulumi.get(__response__, 'custom_notification_template_ref'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        last_modified=pulumi.get(__response__, 'last_modified'),
        name=pulumi.get(__response__, 'name'),
        notification_channel_refs=pulumi.get(__response__, 'notification_channel_refs'),
        notification_conditions=pulumi.get(__response__, 'notification_conditions'),
        org=pulumi.get(__response__, 'org'),
        project=pulumi.get(__response__, 'project'),
        status=pulumi.get(__response__, 'status')))
